==> ver.B.b14.01.tar.gz: ver.B.b14.01/env/src/gbs/lib/view/conf/param_script.c <==
/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/


#include	"stream.h"
#include	"gbview.h"

void
init_param_script(STREAM * st)
{
	s_printf(st,"\n");
	s_printf(st,"<?xl version=\"0.1\" encoding=\"UTF-8\"?>\n");
	s_printf(st,"\n");
	s_printf(st,"<Env0 type=\"raw\">\n");
	s_printf(st,"\t<Define> ^gb-ns xlp://isjhp1.nichibun.ac.jp:8080/gb_metadata\n");
	s_printf(st,"\t</Define>\n");
	s_printf(st,"</Env0>\n");
	s_printf(st,"\n");
	s_printf(st,"\n");
	s_printf(st,"<gv-resource rid=\"4\">\n");
	s_printf(st,"\n");
	s_printf(st,"\t([initial-query type=\"direct\"] (OR\n");
	s_printf(st,"\t\t(URL \"xlp://isjhp2.nichibun.ac.jp:8080/world/00.crd\")\n");
	s_printf(st,"\t\t($ (gb-template1 () \"base\" \"W3C-DTF\" 'now 'now ))))\n");
	s_printf(st,"\n");
	s_printf(st,"\t(window-size 600 400)\n");
	s_printf(st,"\t(font-size 13)\n");
	s_printf(st,"\t(image-enhancement 1 1)\n");
	s_printf(st,"\n");
	s_printf(st,"\t(http-client \"netscape\")\n");
	s_printf(st,"\n");
	s_printf(st,"\n");
	s_printf(st,"</gv-resource>\n");
	s_printf(st,"\n");
	s_printf(st,"\n");
	s_printf(st,"\n");
	s_printf(st,"\n");
}

==> ver.B.b16.14.tar.gz: ver.B.b16.14/env/src/gbs/lib/view/conf/param_script.c <==
/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/


#include	"stream.h"
#include	"gbview.h"

void
init_param_script(STREAM * st)
{
	s_printf(st,"\n");
	s_printf(st,"<?xl version=\"0.1\" encoding=\"UTF-8\"?>\n");
	s_printf(st,"\n");
	s_printf(st,"<Env0 type=\"raw\">\n");
	s_printf(st,"\t<Define> ^gb-ns xlp://isjhp1.nichibun.ac.jp:8080/gb_metadata\n");
	s_printf(st,"\t</Define>\n");
	s_printf(st,"</Env0>\n");
	s_printf(st,"\n");
	s_printf(st,"\n");
	s_printf(st,"<gv-resource rid=\"4\">\n");
	s_printf(st,"\n");
	s_printf(st,"\t([initial-query type=\"direct\"] (OR\n");
	s_printf(st,"\t\t(URL \"xlp://isjhp2.nichibun.ac.jp:8080/world/00.crd\")\n");
	s_printf(st,"\t\t( (gb-template1 () \"base\" \"W3C-DTF\" 'now 'now ))))\n");
	s_printf(st,"\n");
	s_printf(st,"\t(window-size 600 400)\n");
	s_printf(st,"\t(font-size 13)\n");
	s_printf(st,"\t(image-enhancement 1 1)\n");
	s_printf(st,"\n");
	s_printf(st,"\t(http-client \"netscape\")\n");
	s_printf(st,"\t(initial-warp-method 1)\n");
	s_printf(st,"\t(lang \"%s\")\n",get_locale());
	s_printf(st,"\n");
	s_printf(st,"</gv-resource>\n");
	s_printf(st,"\n");
	s_printf(st,"\n");
	s_printf(st,"\n");
	s_printf(st,"\n");
}
